#[repr(u8)]pub enum AlmMatch {
HOURS = 0,
DAYS = 1,
MONTHS = 2,
YEAR = 3,
}Variants
HOURS = 0
If CTRL[ALM_SUBSECS_MATCH_EN] =0, Only seconds, minutes, and hours matched. If CTRL[ALM_SUBSECS_MATCH_EN] =1, Only subseconds, seconds, minutes, and hours matched.
DAYS = 1
If CTRL[ALM_SUBSECS_MATCH_EN] =0, Only seconds, minutes, hours, and days matched. If CTRL[ALM_SUBSECS_MATCH_EN] =1, Only subseconds, seconds, minutes, hours, and days matched.
MONTHS = 2
If CTRL[ALM_SUBSECS_MATCH_EN] =0, Only seconds, minutes, hours, days and months matched. If CTRL[ALM_SUBSECS_MATCH_EN] =1, Only subseconds, seconds, minutes, hours, days and months matched.
YEAR = 3
If CTRL[ALM_SUBSECS_MATCH_EN] =0, Only seconds, minutes, hours, days, months and year (offset) matched. If CTRL[ALM_SUBSECS_MATCH_EN] =1, Only subseconds, seconds, minutes, hours, days, months and year (offset) matched.
Implementations